==> jc-1.4.0.tar.gz: javax/accessibility/AccessibleResourceBundle.h <==
// public class javax.accessibility.AccessibleResourceBundle

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle
// @dep_class 807fe20c7e8705a0 javax_accessibility_AccessibleResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_javax_accessibility_AccessibleResourceBundle_H_
#define _JC_javax_accessibility_AccessibleResourceBundle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$sub_refs	_jc_javax_accessibility_AccessibleResourceBundle$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs	_jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$refs	_jc_javax_accessibility_AccessibleResourceBundle$refs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$nonrefs	_jc_javax_accessibility_AccessibleResourceBundle$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$object	_jc_javax_accessibility_AccessibleResourceBundle$object;

typedef const struct _jc_javax_accessibility_AccessibleResourceBundle$vmethods	_jc_javax_accessibility_AccessibleResourceBundle$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleResourceBundle$vtable	_jc_javax_accessibility_AccessibleResourceBundle$vtable;
typedef const struct _jc_javax_accessibility_AccessibleResourceBundle$vtype	_jc_javax_accessibility_AccessibleResourceBundle$vtype;

// Constructors
extern void _jc_javax_accessibility_AccessibleResourceBundle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_accessibility_AccessibleResourceBundle$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_accessibility_AccessibleResourceBundle$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_javax_accessibility_AccessibleResourceBundle$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_accessibility_AccessibleResourceBundle$method_info$getContents$77295dd4f2da9d10;

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleResourceBundle$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_javax_accessibility_AccessibleResourceBundle$object *);
};

// Vtable
struct _jc_javax_accessibility_AccessibleResourceBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_javax_accessibility_AccessibleResourceBundle$vmethods	javax_accessibility_AccessibleResourceBundle;
};

// Vtype
struct _jc_javax_accessibility_AccessibleResourceBundle$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleResourceBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleResourceBundle$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleResourceBundle$refs {
    _jc_javax_accessibility_AccessibleResourceBundle$sub_refs	javax_accessibility_AccessibleResourceBundle;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleResourceBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs	javax_accessibility_AccessibleResourceBundle;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleResourceBundle$object {
	_jc_javax_accessibility_AccessibleResourceBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleResourceBundle$vtype	*vtype;
	_jc_javax_accessibility_AccessibleResourceBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleResourceBundle$vtype _jc_javax_accessibility_AccessibleResourceBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleResourceBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleResourceBundle$class_object;

#endif	/* _JC_javax_accessibility_AccessibleResourceBundle_H_ */

==> jc-1.4.5.tar.gz: javax/accessibility/AccessibleResourceBundle.h <==
// public class javax.accessibility.AccessibleResourceBundle

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle
// @dep_class 807fe20c7e8705a0 javax_accessibility_AccessibleResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_javax_accessibility_AccessibleResourceBundle_H_
#define _JC_javax_accessibility_AccessibleResourceBundle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$sub_refs	_jc_javax_accessibility_AccessibleResourceBundle$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs	_jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$refs	_jc_javax_accessibility_AccessibleResourceBundle$refs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$nonrefs	_jc_javax_accessibility_AccessibleResourceBundle$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleResourceBundle$object	_jc_javax_accessibility_AccessibleResourceBundle$object;

typedef const struct _jc_javax_accessibility_AccessibleResourceBundle$vmethods	_jc_javax_accessibility_AccessibleResourceBundle$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleResourceBundle$vtable	_jc_javax_accessibility_AccessibleResourceBundle$vtable;
typedef const struct _jc_javax_accessibility_AccessibleResourceBundle$vtype	_jc_javax_accessibility_AccessibleResourceBundle$vtype;

// Constructors
extern void _jc_javax_accessibility_AccessibleResourceBundle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_accessibility_AccessibleResourceBundle$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_accessibility_AccessibleResourceBundle$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_javax_accessibility_AccessibleResourceBundle$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_accessibility_AccessibleResourceBundle$method_info$getContents$77295dd4f2da9d10;

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleResourceBundle$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_javax_accessibility_AccessibleResourceBundle$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_accessibility_AccessibleResourceBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_javax_accessibility_AccessibleResourceBundle$vmethods	javax_accessibility_AccessibleResourceBundle;
};

// Vtype
struct _jc_javax_accessibility_AccessibleResourceBundle$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleResourceBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleResourceBundle$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleResourceBundle$refs {
    _jc_javax_accessibility_AccessibleResourceBundle$sub_refs	javax_accessibility_AccessibleResourceBundle;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleResourceBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_javax_accessibility_AccessibleResourceBundle$sub_nonrefs	javax_accessibility_AccessibleResourceBundle;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleResourceBundle$object {
	_jc_javax_accessibility_AccessibleResourceBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleResourceBundle$vtype	*vtype;
	_jc_javax_accessibility_AccessibleResourceBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleResourceBundle$vtype _jc_javax_accessibility_AccessibleResourceBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleResourceBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleResourceBundle$class_object;

#endif	/* _JC_javax_accessibility_AccessibleResourceBundle_H_ */
